@@ -1,22 +1,5 @@
 package Data::Alias;
 
-use 5.008001;
-
-use strict;
-use warnings;
-
-our $VERSION = '1.25_01';
-
-use base 'Exporter';
-use base 'DynaLoader';
-
-our @EXPORT = qw(alias);
-our @EXPORT_OK = qw(alias copy deref);
-our %EXPORT_TAGS = (all => \@EXPORT_OK);
-
-bootstrap Data::Alias $VERSION;
-pop our @ISA;
-
 =head1 NAME
 
 Data::Alias - Comprehensive set of aliasing operations
@@ -65,21 +48,12 @@ Aliasing occurs in Perl for example in for-loops and sub-calls:
     }
 
 Data::Alias is a module that allows you to apply "aliasing semantics" to a 
-section of code, causing aliases to be made wherever Perl would normally make 
+section of code, causing aliases to be made whereever Perl would normally make 
 copies instead.  You can use this to improve efficiency and readability, when 
 compared to using references.
 
 The exact details of aliasing semantics are below under L</DETAILS>.
 
-Perl 5.22 added some support for aliasing to the Perl core.  It has a
-different syntax, and a different set of operations, from that supplied by
-this module; see L<perlref/Assigning to References>.  The core's aliasing
-facilities are implemented more robustly than this module and are better
-supported.  If you can rely on having a sufficiently recent Perl version,
-you should prefer to use the core facility rather than use this module.
-If you are already using this module and are now using a sufficiently
-recent Perl, you should attempt to migrate to the core facility.
-
 =head1 SYNTAX
 
 =head2 alias I<EXPR> | alias I<BLOCK>
@@ -110,15 +84,6 @@ behaves like:
 
     $$scalarref, @$arrayref, %$hashref
 
-Where an array or hash reference is given, the returned list does not
-include the array or hash as an lvalue; the array/hash is expanded and
-the list includes its elements.  Scalars, including the elements of an
-array/hash, I<are> treated as lvalues, and can be enreferenced using
-the C<\> operator or aliased to using the C<alias> operator.  This is
-slightly different from what you'd get using the built-in dereference
-operators: C<@$arrayref> references the array as an lvalue, so C<\>
-or C<alias> can operate on the array itself rather than just its elements.
-
 =head1 EXAMPLES
 
 A common usage of aliasing is to make an abbreviation for an expression, to 
@@ -214,11 +179,9 @@ C<$var2> can be anything that is valid on the left-side of an alias-assignment.
     alias $var ||= $foo;
     alias $var //= $foo; # (perl 5.9.x or later)
 
-=item whole aggregate assignment from whole aggregate
+=item whole aggregate assignment
 
-This occurs where the expressions on both sides of the assignment operator
-are purely complete arrays or hashes.
-The entire aggregate is aliased, not merely the contents.  
+These alias entire aggregates (arrays or hashes), not merely their contents.  
 This means for example that C<\@lexarray == \@foo>.
 
     alias my @lexarray = @foo;
@@ -235,32 +198,19 @@ and analogously to assignment to scalar dereference, these will change C<$ref>
 to reference the aggregate, if C<$ref> was undef or already a reference.  If 
 C<$ref> is a string or glob, the corresponding package variable is aliased.
 
-Anything more complex than a whole-aggregate expression on either side,
-even just enclosing the aggregate expression in parentheses, will prevent
-the assignment qualifying for this category.  It will instead go into
-one of the following two categories.  Parenthesisation is the recommended
-way to avoid whole-aggregate aliasing where it is unwanted.  If you want
-to merely replace the contents of the left-side aggregate with aliases
-to the contents of the right-side aggregate, parenthesise the left side.
+If the right-side expression is not an aggregate (of the same type), then a new 
+one is implicitly constructed.  This means:
 
-=item whole aggregate assignment from list
-
-If the left-side expression is purely a complete array or hash,
-and the right-side expression is not purely a matching aggregate, then a new 
-aggregate is implicitly constructed.  This means:
-
-    alias my @lexfoo = (@foo);
     alias my @array = ($x, $y, $z);
     alias my %hash = (x => $x, y => $y);
 
 is translated to:
 
-    alias my @lexfoo = @{ [@foo] };
     alias my @array = @{ [$x, $y, $z] };
     alias my %hash = %{ {x => $x, y => $y} };
 
 If you want to merely replace the contents of the aggregate with aliases to the 
-contents of another aggregate, rather than create a new aggregate, you can 
+contents of another aggregate, but not alias the aggregates themselves, you can 
 force list-assignment by parenthesizing the left side, see below.
 
 =item list assignment
@@ -280,7 +230,7 @@ last item, its contents are replaced by the list of all remaining right-side
 elements.  C<undef> can also appear on the left side to skip one corresponding 
 item in the right-side list.
 
-Beware when putting a parenthesised list on the left side.  Just like Perl 
+Beware when putting a parenthesized list on the left side.  Just like Perl 
 parses C<print (1+2)*10> as C<(print(1+2))*10>, it would parse C<alias ($x, $y) 
 = ($y, $x)> as C<(alias($x, $y)) = ($y, $x)> which does not do any aliasing, 
 and results in the "Useless use of alias" warning, if warnings are enabled.
@@ -321,23 +271,8 @@ An attempt to do any of these on tied (or "magical") array will result in a
 
 =item Returning an alias
 
-Returns aliases from the current C<sub> or C<eval>.  Normally this only
-happens for lvalue subs, but C<alias return> can be used in any sub.
-Lvalue subs only work for scalar return values, but C<alias return>
-can handle a list of return values.
-
-A sub call will very often copy the return value(s) immediately after
-they have been returned.  C<alias return> can't prevent that.  To pass
-an alias through a sub return and into something else, the call site
-must process the return value using an aliasing operation, or at least a
-non-copying one.  For example, ordinary assignment with the sub call on
-the right hand side will copy, but if the call site is in the scope of an
-C<alias> pragma then the assignment will instead alias the return value.
-
-When alias-returning a list of values from a subroutine, each individual
-value in the list is aliased.  The list as a whole is not aliasable;
-it is not an array.  At the call site, a list of aliases can be captured
-into separate variables or into an array, by an aliasing list assignment.
+Returns aliases from the current C<sub> or C<eval>.  Normally this only happens 
+for lvalue subs, but C<alias return> can be used in any sub.
 
 =item Subroutines and evaluations
 
@@ -364,7 +299,7 @@ subroutine or evaluation.
 
 Use of local inside C<alias> usually behaves the same as local does in general, 
 however there is a difference if the variable is tied:  in this case, Perl 
-doesn't localise the variable at all but instead preserves the tie by saving a 
+doesn't localize the variable at all but instead preserves the tie by saving a 
 copy of the current value, and restoring this value at end of scope.
 
     alias local $_ = $string;
@@ -383,11 +318,12 @@ replaces operations within the scope of C<alias> by aliasing variants.
 For those familiar with perl's internals:  it triggers on a ck_rv2cv which 
 resolves to the imported C<alias> sub, and does a parser hack to allow the 
 C<alias BLOCK> syntax.  When the ck_entersub is triggered that corresponds to 
-it, the op is marked to be found later.  The actual work is done in a peep-hook,
-which processes the marked entersub 
+it, the op is marked to be found later.  The actual work is done in a peep-hook 
+which is installed on the ck_rv2cv trigger, and processes the marked entersub 
 and its children, replacing the pp_addrs with aliasing replacements.  The peep 
 hook will also take care of any subs defined within the lexical (but not 
-dynamical) scope between the ck_rv2cv and the ck_entersub.
+dynamical) scope between the ck_rv2cv and the ck_entersub.  When no marked 
+entersubs remain, the Data::Alias-peeper stops and is deinstalled.
 
 =head1 KNOWN ISSUES
 
@@ -405,6 +341,13 @@ When aliasing a lexical that was declared outside the current subroutine, a
 compile-time warning is generated "Aliasing of outer lexical variable has 
 limited scope" (warnings category "closure").
 
+=item Platform support
+
+Some platforms, notably Windows and AIX, will give link errors when attempting 
+to build Data::Alias.  This cannot be fixed.  When using Windows, you can use 
+perl inside cygwin (L<http://www.cygwin.com/>) instead, where Data::Alias does 
+work.
+
 =back
 
 =head1 ACKNOWLEDGEMENTS
@@ -414,19 +357,29 @@ the Amsterdam Perl Mongers, for their valuable feedback.
 
 =head1 AUTHOR
 
-Matthijs van Duin <xmath@cpan.org> developed the module originally,
-and maintained it until 2007.  Andrew Main (Zefram) <zefram@fysh.org>
-updated it to work with Perl versions 5.11.0 and later.
+Matthijs van Duin <xmath@cpan.org>
 
-=head1 LICENSE
-
-Copyright (C) 2003-2007  Matthijs van Duin.
-Copyright (C) 2010, 2011, 2013, 2015, 2017
-Andrew Main (Zefram) <zefram@fysh.org>.
-All rights reserved.
+Copyright (C) 2003, 2004, 2006  Matthijs van Duin.  All rights reserved.
 This program is free software; you can redistribute it and/or modify 
 it under the same terms as Perl itself.
 
 =cut
 
-__PACKAGE__
+use 5.008001;
+
+use strict;
+use warnings;
+
+our $VERSION = '1.01';
+
+use base 'Exporter';
+use base 'DynaLoader';
+
+our @EXPORT = qw(alias);
+our @EXPORT_OK = qw(alias copy deref);
+our %EXPORT_TAGS = (all => \@EXPORT_OK);
+
+bootstrap Data::Alias $VERSION;
+pop our @ISA;
+
+1;
